
# Type: percentage frequency value




URI: [biolink:PercentageFrequencyValue](https://w3id.org/biolink/vocab/PercentageFrequencyValue)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Double](types/Double.md) |
| Root (builtin) type | | **float** |
